
## CATO-CLI - mutation.policy.appTenantRestriction:
[Click here](https://api.catonetworks.com/documentation/#mutation-appTenantRestriction) for documentation on this operation.

### Usage for mutation.policy.appTenantRestriction:

`catocli mutation policy appTenantRestriction -h`
